@@ -63,7 +63,7 @@ int main(int argc, char **argv)
 	char ndef_type = 0;
 	unsigned char usb_mode = 0;
 	unsigned char cr_timeout = 0;
-	unsigned char autoeject_timeout = 0;
+	unsigned short autoeject_timeout = 0;
 	int num_modes_seen = 0;
 	bool zap = false;
 
